@@ -90,11 +90,11 @@ class Main(gtk.Application, Tools):
     menu_items = [
         (menus.file_menu, 'quit', 'application-exit', _('_Quit'),
          '<control>q', self._onQuit),
-        (menus.edit_menu, 'preferences', 'preferences-system-symbolic', _('_Preferences…'),
+        (menus.edit_menu, 'preferences', 'preferences-system', _('_Preferences…'),
          '<control>p', self._onShowPreferences),
-        (menus.help_menu, 'contents', 'help-browser-symbolic', _('_Contents'),
+        (menus.help_menu, 'contents', 'help-browser', _('_Contents'),
          'F1', self._onHelp),
-        (menus.help_menu, 'about', 'help-about-symbolic', _('_About'),
+        (menus.help_menu, 'about', 'help-about', _('_About'),
          None, self._onAbout)]
 
     self.addMenuItems(menu_items)
@@ -102,7 +102,6 @@ class Main(gtk.Application, Tools):
     self.last_focused = None
     self.window.show_all()
 
-    GLib.timeout_add(200, self._pumpEvents)
     try:
       # async is a reserved keyword in Python 3.7+, so we pass the args as dict
       pyatspi.Registry.start(**{'async': True, 'gil': False})
@@ -153,10 +152,6 @@ class Main(gtk.Application, Tools):
     for menu, name, icon_name, label, accel, callback in menu_items:
       self.addMenuItem(menu, name, icon_name, label, accel, callback)
 
-  def _pumpEvents(self):
-    pyatspi.Registry.pumpQueuedEvents()
-    return True
-
   def _shutDown(self):
     '''
     Cleans up any object instances that need explicit shutdown.
@@ -195,9 +190,9 @@ class Main(gtk.Application, Tools):
     uri = "help:accerciser"
     if page:
         uri += "/%s" % page
-    gtk.show_uri(gdk.Screen.get_default(),
-                 uri,
-                 gtk.get_current_event_time())
+    gtk.show_uri_on_window(self.window,
+                           uri,
+                           gtk.get_current_event_time())
     return True
 
   def _onShowPreferences(self, action, data=None):
